package com.style24.admin.biz.dao;

import java.util.Collection;

import com.style24.core.support.annotation.ShopDs;
import com.style24.persistence.domain.Goods;
import com.style24.persistence.domain.OrderSample;

/**
 * 주문관리 Dao
 *
 * @author jsh77b
 * @since 2020. 11. 16
 */
@ShopDs
public interface TsaPgDao {

	/* 주문 샘플 데이터 (추후 삭제 예정) */
	Collection<Goods> getOrderSampleGoodsInfo(Goods goods);
	Goods getOrderSampleGoodsStock(Goods goods);
	int createOrderSample(OrderSample orderSample);
	int createDelveryAddrSample(OrderSample orderSample);
	int createDeliveryFeeSample(OrderSample orderSample);
	int createOrderDetailSample(OrderSample orderSample);
	int createOrderDetailItemSample(OrderSample orderSample);
	int createPaymentSample(OrderSample orderSample);
	int updateDeliveryFeeSample(OrderSample orderSample);
	/* //주문 샘플 데이터 (추후 삭제 예정) */

}













